==> gcube-model-1.1.0-20191010.145805-50-sources.jar: org/gcube/resourcemanagement/model/impl/entities/facets/SoftwareFacetImpl.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.model.impl.entities.facets;

import org.gcube.informationsystem.model.impl.entities.FacetImpl;
import org.gcube.resourcemanagement.model.reference.entities.facets.NameProperty;
import org.gcube.resourcemanagement.model.reference.entities.facets.SoftwareFacet;

import com.fasterxml.jackson.annotation.JsonTypeName;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonTypeName(value=SoftwareFacet.NAME)
public class SoftwareFacetImpl extends FacetImpl implements SoftwareFacet, NameProperty {

	/**
	 * Generated Serial version UID
	 */
	private static final long serialVersionUID = 1062768788238515868L;
	
	
	protected String name;
	protected String group;
	protected String version;
	
	protected String description;
	protected String qualifier;
	protected boolean optional;
	
	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public void setName(String name) {
		this.name = name;
	}

	@Override
	public String getGroup() {
		return this.group;
	}

	@Override
	public void setGroup(String group) {
		this.group = group;
	}

	@Override
	public String getVersion() {
		return this.version;
	}

	@Override
	public void setVersion(String version) {
		this.version = version;
	}

	@Override
	public String getDescription() {
		return this.description;
	}

	@Override
	public void setDescription(String description) {
		this.description = description;
	}

	@Override
	public String getQualifier() {
		return this.qualifier;
	}

	@Override
	public void setQualifier(String qualifier) {
		this.qualifier = qualifier;
	}

	@Override
	public boolean isOptional() {
		return this.optional;
	}

	@Override
	public void setOptional(boolean optional) {
		this.optional = optional;
	}

}

==> gcube-model-3.0.0-20201014.163415-28-sources.jar: org/gcube/resourcemanagement/model/impl/entities/facets/SoftwareFacetImpl.java <==
/**
 * 
 */
package org.gcube.resourcemanagement.model.impl.entities.facets;

import org.gcube.com.fasterxml.jackson.annotation.JsonTypeName;
import org.gcube.informationsystem.model.impl.entities.FacetImpl;
import org.gcube.resourcemanagement.model.reference.entities.facets.NameProperty;
import org.gcube.resourcemanagement.model.reference.entities.facets.SoftwareFacet;

/**
 * @author Luca Frosini (ISTI - CNR)
 */
@JsonTypeName(value=SoftwareFacet.NAME)
public class SoftwareFacetImpl extends FacetImpl implements SoftwareFacet, NameProperty {

	/**
	 * Generated Serial version UID
	 */
	private static final long serialVersionUID = 1062768788238515868L;
	
	
	protected String name;
	protected String group;
	protected String version;
	
	protected String description;
	protected String qualifier;
	protected boolean optional;
	
	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public void setName(String name) {
		this.name = name;
	}

	@Override
	public String getGroup() {
		return this.group;
	}

	@Override
	public void setGroup(String group) {
		this.group = group;
	}

	@Override
	public String getVersion() {
		return this.version;
	}

	@Override
	public void setVersion(String version) {
		this.version = version;
	}

	@Override
	public String getDescription() {
		return this.description;
	}

	@Override
	public void setDescription(String description) {
		this.description = description;
	}

	@Override
	public String getQualifier() {
		return this.qualifier;
	}

	@Override
	public void setQualifier(String qualifier) {
		this.qualifier = qualifier;
	}

	@Override
	public boolean isOptional() {
		return this.optional;
	}

	@Override
	public void setOptional(boolean optional) {
		this.optional = optional;
	}

}
